@@ -22,12 +22,13 @@ from pathlib import Path
 
 import toml
 
-from . import terminal
+from . import terminal, database
 from .xdict import XDict
-from .tools import rotate, grouper
+from .tools import rotate, grouper, read_text
 from .configfile import StandardConfigFile
 
 with open(Path(__file__).parent / 'meta/pyproject.toml', 'r') as f:
     __version__ = toml.load(f)['tool']['poetry']['version']
 
-__all__ = [terminal, XDict, rotate, grouper, StandardConfigFile]
+__all__ = [terminal, XDict, rotate, grouper, read_text, StandardConfigFile,
+           database]
